#!/usr/bin/gnuplot

G = 6.67e-11
M_S = 1.989e30
M_E = 5.972e24
au = 1.496e11
yr = 365.25*86400.0
cm = 1.e-2
g = 1.e-3

dt = 0.314159
P = 20*dt

f(x) = x/1e6
g(m) = m*M_S/M_E
h(m) = 6.0*m

n(r) = sqrt(G*M_S/r**3)
dadt(r,m,Gamma_cgs) = 2*Gamma_cgs*g*cm**2/(r*au*n(r*au)*m*M_S) / (1e-6*au/yr)

########################################################################

set term pdf enh color solid font "DejaVuSans,10" size 7.5cm,5.5cm
set out "dadt21_mmsn.pdf"

x1=-0.05
x2=1.05
set xr [x1:x2]
y1=0.20
y2=1.80
set yr [y1:y2]
c1=-4.0
c2=4.0
t1=-0.2
t2=1.2
tmp=0.1e6

set palette defined (\
  (c1  -c1)/(c2-c1) '#aa00ff',\
  (-1.5-c1)/(c2-c1) 'blue'   ,\
  (-0.5-c1)/(c2-c1) 'cyan'  ,\
  ( 0.0-c1)/(c2-c1) 'white' ,\
  (+0.5-c1)/(c2-c1) 'orange',\
  (c2  -c1)/(c2-c1) 'red'    \
  )

set cbtics 1.0 scale 0.25
set pm3d map
set lmargin 5.0
set rmargin 0.0
set bmargin 3.3

set style line 1 lc palette z lw 0.0 pt 7 ps var
set style line 2 lc 'black'   lw 0.2 pt 6 ps var

set multiplot

########################################################################
########################################################################

set origin 0,0
a=0.57
b=1.15
set size a,b
set xl "{/CMMI10 m} {/csr10 [M_E]}" font "DejaVuSans,12" offset 0.0,1.2
set yl "{/CMMI10 a} {/csr10 [au]}" font "DejaVuSans,12" offset -1,0
set xr [x1:x2]
set yr [y1:y2]
set cbr [c1:c2]
set xtics 0.5 format "%.1g" scale 0.25 offset 0,1.0
set ytics format "%.1f" scale 0.5
set nocolorbox
set noarrow
set lmargin 5.0
set rmargin 0.0
set bmargin 1.4
set tmargin 0.0

sp \
  "../../5planet_stable_FLUX2e-4/torquemap/massdataGamma0.out_10" u (g($2)):1:(dadt($1,$2,$7)) not w pm3d,\
  "<awk '($1==0.0)'   migrate_lunar_0.dat" u 3:2:4:(h($3)) not w p ls 2

########################################################################

d=0.46
set origin d,0
c=0.47
set size c,b
set xl "{/CMMI10 t} {/csr10 [Myr]}" font "DejaVuSans,12" offset 0.0,1.2
set yl ""
set cbl "{/csr10 d}{/CMMI10 a}{/csr10 /d}{/CMMI10 t} {/csr10 [10^{-6}} {{/csr10 au/yr]} {/DejaVuSans=8 (MMSN)}" font "DejaVuSans,12" offset 0.7,0
set xr [t1:t2]
set ytics format ""
set colorbox vertical user origin 0.86,0.164 size 0.02,0.817
set lmargin 0.0

sp \
  "migrate_lunar_0.dat" u ($1/1.e6):2:4:2 not w l lc rgb '#aa000000' lw 2,\
  "<awk '($1==0.0)'   migrate_lunar_0.dat" u (f($1-tmp)):($2-tmp*$4):4:(h($3)):($4/1.e-6) not w p ls 1,\
  "<awk '($1==1.0e6)' migrate_lunar_0.dat" u (f($1+tmp)):($2+tmp*$4):4:(h($3)):($4/1.e-6) not w p ls 1,\
  "<awk '($1==0.0)'   migrate_lunar_0.dat" u (f($1-tmp)):($2-tmp*$4):4:(h($3))            not w p ls 2,\
  "<awk '($1==1.0e6)' migrate_lunar_0.dat" u (f($1+tmp)):($2+tmp*$4):4:(h($3))            not w p ls 2

########################################################################

q


