#!/usr/bin/env python

import math
import sys

G = 6.67e-11
M_S = 1.99e30
M_E = 5.97e24
au = 1.496e11
yr = 365.25*86400.0
cm = 1.e-2
g = 1.e-3

def a_Hill(a):
    return a*(1 + multiple*0.5*((q+q_)/3.)**(1./3.))/(1 - multiple*0.5*((q+q_)/3.)**(1./3.))

def n(r):
    return math.sqrt(G*M_S/r**3)

def dadt(r,m,Gamma_cgs):
    return 2*Gamma_cgs*g*cm**2/(r*au*n(r*au)*m*M_S) / (au/yr)

totmass = 2.0*M_E
multiple = 9.75
factor = 1.0260

a_ = 0.45
m_ = 0.05*M_E
tot = 0.0

M = []
A = []
while tot < totmass:
    m = m_
    M.append(m/M_E)
    m_ = m*factor
    q = m/M_S
    q_ = m_/M_S
    a = a_
    A.append(a)
    a_ = a_Hill(a)
    tot += m

#print A
#print M
print "# t [yr] & a [au] & m [M_E] & da/dt [au/yr]"

DT = 1.0e6

i = 0
for line in sys.stdin:
    l = line.split()
    if len(l) > 0 and line[0] != "#":
        a = float(l[0])
        m = float(l[1])*M_S/M_E
        Gamma_cgs = float(l[6])

        if abs(a-A[i]) < 0.005 and abs(m-M[i]) < 0.001:

            dadt_ = dadt(a,m*M_E/M_S,Gamma_cgs)
            print "%.8e  %.4f %.4f  %.8e  <-- %.4f %.4f" % (0.0, a, m, dadt_, A[i], M[i])
            print "%.8e  %.4f %.4f  %.8e  <-- %.4f %.4f" % (DT, a + dadt_*DT, m, dadt_, A[i], M[i])
            print ""
            print ""

            i += 1

        if i > len(A)-1:
            break


