#!/usr/bin/gnuplot

M_S = 1.989e30
M_E = 5.972e24
R_E = 6378.e3

e_V = 0.007
e_E = 0.016

dt = 0.314159
P = 20*dt

f(t) = t/P
g(m) = m*M_S/M_E * 4.0
t0 = 23000.

r(a,i,j) = a*(1.0*i/j)**(-2./3.)

load "config.plt"
set out "nbody.orbits.at3.eps"

set autoscale x
set xr [0:26000]
set autoscale y
set ytics 0.010
set mytics 1
set nokey

set size 0.9,1.65
set multiplot
set origin 0,0
set size 0.9,0.4

set label "Mercury" at t0,0.45+0.002 center font "Helvetica,12"

p \
  "<awk '($1==1)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):(sqrt($13**2+$14**2+$15**2)) not w d ls 1,\
  "<awk '($1==1)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):3 t "1" w l ls 1 lw 2,\
  0.45  w l lt 0 not,\
  "<tail -5 ../5planet_1over10/out_META/nbody.orbits.dat | awk '($1==1)'" u (t0):3:(g($9)) not w p ls 1 pt 7 ps var

set origin 0,0.31
set xl ""
set xtics format ""
set yr [0.71:0.74]
set nolabel
set label "Venus" at t0,0.723+0.008 center font "Helvetica,12"
x3=3000
y3=0.732
set arrow from x3,y3*(1-e_V) to x3,y3*(1+e_V) heads size 100,45 lt 9
set label sprintf("  {/Helvetica-Oblique e} = %.3f", e_V) at x3,y3 font "Helvetica,12"

p \
  "<awk '($1==2)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):(sqrt($13**2+$14**2+$15**2)) not w d ls 2,\
  "<awk '($1==2)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):3 t "2" w l ls 2 lw 2,\
  0.723 w l lt 0 not,\
  "<tail -5 ../5planet_1over10/out_META/nbody.orbits.dat | awk '($1==2)'" u (t0):3:(g($9)) not w p ls 2 pt 7 ps var

set origin 0,0.62
set nolabel
set noarrow
set autoscale y
set ytics 0.020
set mytics 1
set label "0.5 Earth" at t0,1.000+0.005 center font "Helvetica,10"
y3=0.98
set arrow from x3,y3*(1-e_E) to x3,y3*(1+e_E) heads size 100,45 lt 9
set label sprintf("  {/Helvetica-Oblique e} = %.3f", e_E) at x3,y3 font "Helvetica,12"

p \
  "<awk '($1==3)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):(sqrt($13**2+$14**2+$15**2)) not w d ls 3,\
  "<awk '($1==3)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):3 t "3" w l ls 3 lw 2,\
  1.0   w l lt 0 not,\
  "<tail -5 ../5planet_1over10/out_META/nbody.orbits.dat | awk '($1==3)'" u (t0):3:(g($9)) not w p ls 3 pt 7 ps var

set origin 0,0.93
set nolabel
set noarrow
set label "0.5 Earth" at t0,1.220+0.018 center font "Helvetica,10"
set label "4:3 resonance w. Mars" at 1000,graph 0.5 font "Helvetica,12" tc 'gray'

p \
  "<awk '($1==4)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):(sqrt($13**2+$14**2+$15**2)) not w d ls 4,\
  "<awk '($1==4)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):3 t "4" w l ls 4 lw 2,\
  "<awk '($1==5)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):(r($3,4,3)) not w l lt 9 lw 2 dt 3,\
  1.25  w l lt 0 not,\
  "<tail -5 ../5planet_1over10/out_META/nbody.orbits.dat | awk '($1==4)'" u (t0):3:(g($9)) not w p ls 4 pt 7 ps var

set origin 0,1.24
set nolabel
set label "Mars" at t0,1.511-0.008 center font "Helvetica,12"

p \
  "<awk '($1==5)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):(sqrt($13**2+$14**2+$15**2)) not w d ls 5,\
  "<awk '($1==5)' ../5planet_1over10/out_META/nbody.orbits.dat" u (f($2)):3 t "5" w l ls 5 lw 2,\
  1.523 w l lt 0 not,\
  "<tail -5 ../5planet_1over10/out_META/nbody.orbits.dat | awk '($1==5)'" u (t0):3:(g($9)) not w p ls 5 pt 7 ps var

#pa -1

unset multiplot

system "patch nbody.orbits.at3.eps config.diff"

q

