#!/usr/bin/gnuplot

GM_SI = 1.32712440018e20
AU_SI = 149597870700.0
MSOL_SI = 1.98855e30
SIGMA2CGS = MSOL_SI*1000.0/(AU_SI*100.0)**2

R_STANDARD = 8.3144598
MMW = 2.4
R_SI = R_STANDARD/(MMW*0.001)
T2SI = GM_SI/R_SI/AU_SI

ADIABIND = 1.4
MOLWEIGTH = 1.0
GASCONST = 1.0
SQRT_ADIABIND_INV = 1.0/sqrt(ADIABIND)
SQRT2PI_INV = 1.0/sqrt(2.0*pi)

MSOL_SI = 1.98855e30
RHO2CGS = MSOL_SI*1000.0/(AU_SI*100.0)**3

Omega(r) = r**(-1.5)
cs(T) = sqrt(ADIABIND*T/MOLWEIGTH*GASCONST)
H(r,T) = cs(T)/Omega(r)*SQRT_ADIABIND_INV

rho(r,Sigma,T) = Sigma/H(r,T)*SQRT2PI_INV

T_MRI = 1000
T_evaporation = 1500

########################################################################

AU_SI = 149597870700.0
MSOL_SI = 1.98855e30
OPA2CU = MSOL_SI*1000.0/(AU_SI*100.0)**2

########################################################################

set term post eps enh color dashed "Helvetica" 18
set out "profiles_kappa4.eps"
set size 0.8,1.66

set multiplot
set origin 0,0
set size 0.8,0.50

set xl "{/Helvetica-Oblique r} [au]"
set yl "{/Symbol-Oblique S} [g cm^{-2}]" offset 1,0

load "config.plt"

r(i) = Rmin+(Rmax-Rmin)*int(i/Nsec)/Nr
f(Sigma) = Sigma*SIGMA2CGS
g(T) = T*T2SI

set xr [Rmin:Rmax]
y1=-100
y2=4500
set yr [y1:y2]
set ytics 1000
#set logscale y
set key at graph 0.875,graph 0.9 spacing 1.2 samplen 1.0 font "Helvetica,14"
set grid noxtics noytics front

set lmargin 7.8
set rmargin 1.5

set style line 1 lt 1 lw 5
set style line 2 lt 2 lw 4
set style line 3 lt 3 lw 3
set style line 4 lt 4 lw 2 dt 2
set style line 5 lt 8 lw 2 dt 3
set style line 6 lt 8 lw 1 dt 4

tmp=180; set arrow from 17,tmp to 17.5,tmp lt 0 

p \
  "box.dat" u (Rmin+$1*(1.2*Rmin-Rmin)):(y1+$2*(y2-y1)) w filledcurves not lc rgb '#cccccc',\
  "box.dat" u (Rmax-$1*(Rmax-0.9*Rmax)):(y1+$2*(y2-y1)) w filledcurves not lc rgb '#dddddd',\
  "../../5planet_stable_FLUX2e-4/test_relax2/gasdens0120.cfg"      u (r($0)):(f($1)) t "{/Symbol S}_0 = 750 g cm^{-2}, slope -1.5" w l ls 1,\
  "../../5planet_1over10/test_relax2/gasdens0120.cfg"              u (r($0)):(f($1)) t "{/Symbol S}_0 = 75 g cm^{-2}"              w l ls 4,\
  "../../5planet_stable_SEMENOV/test_relax2/gasdens0120.cfg"       u (r($0)):(f($1)) t "Semenov opacities"                         w l ls 5,\
  "../../5planet_inverse_NU2.0_-0.5/test_relax/gasdens0060.cfg"    u (r($0)):(f($1)) t "MRI-active"                                w l ls 2

########################################################################

set origin 0,0.44
set size 0.8,0.45

set xl ""
set yl "{/Helvetica-Oblique T} [K]" offset 1.0,0
set yr [0:1800]
set xtics format ""
set ytics 500
set nokey
set noarrow

tmp=0.8
set label "{/=14{/Helvetica-Oblique T}_{MRI}}" at graph tmp,first T_MRI+120
set label "{/=14{/Helvetica-Oblique T}_{ev}}"  at graph tmp,first T_evaporation+120

p \
  "box.dat" u (Rmin+$1*(1.2*Rmin-Rmin)):(y1+$2*(y2-y1)) w filledcurves not lc rgb '#cccccc',\
  "box.dat" u (Rmax-$1*(Rmax-0.9*Rmax)):(y1+$2*(y2-y1)) w filledcurves not lc rgb '#dddddd',\
  "../../5planet_stable_FLUX2e-4/test_relax2/gastemper0120.cfg"      u (r($0)):(g($1)) t "5planet stable"      w l ls 1,\
  "../../5planet_1over10/test_relax2/gastemper0120.cfg"              u (r($0)):(g($1)) t "5planet 1over10"     w l ls 4,\
  "../../5planet_stable_SEMENOV/test_relax2/gastemper0120.cfg"       u (r($0)):(g($1)) t "5planet Semenov"     w l ls 5,\
  "../../5planet_inverse_NU2.0_-0.5/test_relax/gastemper0060.cfg"    u (r($0)):(g($1)) t "5planet inverse"     w l ls 2,\
  T_MRI         w l not lt 0,\
  T_evaporation w l not lt 0

########################################################################

set origin 0,0.83

set yl "{/Helvetica-Oblique h} = {/Helvetica-Oblique H}/{/Helvetica-Oblique r}" offset 1,0
y1=0.01
y2=0.060
set yr [y1:y2]
set ytics 0.01
set nokey
set nolabel

tmp=3.6; set arrow from tmp,graph 0 to tmp,graph 1 nohead lt 0
set label "{/=12 snowline}"    at tmp+0.2,graph 0.4 center rotate by 90
tmp=7.3; set arrow from tmp,graph 0 to tmp,graph 1 nohead lt 0
set label "{/=12 viscosity}"   at tmp-0.36,graph 0.6 center rotate by 90
set label "{/=12 irradiation}" at tmp+0.20,graph 0.6 center rotate by 90

p \
  "box.dat" u (Rmin+$1*(1.2*Rmin-Rmin)):(y1+$2*(y2-y1)) w filledcurves not lc rgb '#cccccc',\
  "box.dat" u (Rmax-$1*(Rmax-0.9*Rmax)):(y1+$2*(y2-y1)) w filledcurves not lc rgb '#dddddd',\
  "../../5planet_stable_FLUX2e-4/test_relax2/gastemper0120.cfg"      u (r($0)):(H(r($0),$1)/r($0)) t "5planet stable"      w l ls 1,\
  "../../5planet_1over10/test_relax2/gastemper0120.cfg"              u (r($0)):(H(r($0),$1)/r($0)) t "5planet 1over10"     w l ls 4,\
  "../../5planet_stable_SEMENOV/test_relax2/gastemper0120.cfg"       u (r($0)):(H(r($0),$1)/r($0)) t "5planet Semenov"     w l ls 5,\
  "../../5planet_inverse_NU2.0_-0.5/test_relax/gastemper0060.cfg"    u (r($0)):(H(r($0),$1)/r($0)) t "5planet inverse"     w l ls 2,\

########################################################################

set origin 0,1.22

set yl "{/Symbol-Oblique k} [cm^2 g^{-1}]" offset 0.5,0
y1=0.5
y2=50
set yr [y1:y2]
set ytics auto
set logscale y
set noarrow
set nolabel

load "opacity_ZHU.plt"

opacity_ZHU(r,Sigma,T) = kappa_ZHU(rho(r,Sigma,T)*RHO2CGS,T*T2SI)

set label "C"    at 1.04,33 center font "Helvetica,14" tc lt 1
set label "Si"   at 0.45,10 center font "Helvetica,14" tc lt 1
set label "C"    at 0.46,32 center font "Helvetica,14" tc lt 4
set label "H_2O" at 1.05, 8 center font "Helvetica,14" tc lt 4
set label "C"    at 0.52,32 center font "Helvetica,14" tc lt 2
set label "Fe, Si"               at 0.47, 1.5 center font "Helvetica,12"
set label "troilit"              at 0.75, 1.5 center font "Helvetica,12"
set label "refractory\norganics" at 1.15, 1.5 center font "Helvetica,12"
set label "volatile\norganics"   at 1.50, 1.5 center font "Helvetica,12"

p \
  "box.dat" u (Rmin+$1*(1.2*Rmin-Rmin)):(y1+$2*(y2-y1)) w filledcurves not lc rgb '#cccccc',\
  "box.dat" u (Rmax-$1*(Rmax-0.9*Rmax)):(y1+$2*(y2-y1)) w filledcurves not lc rgb '#dddddd',\
  "<paste ../../5planet_stable_FLUX2e-4/test_relax2/gasdens0120.cfg       ../../5planet_stable_FLUX2e-4/test_relax2/gastemper0120.cfg     " u (r($0)):(opacity_ZHU(r($0),$1,$2)) w l ls 1,\
  "<paste ../../5planet_1over10/test_relax2/gasdens0120.cfg               ../../5planet_1over10/test_relax2/gastemper0120.cfg             " u (r($0)):(opacity_ZHU(r($0),$1,$2)) w l ls 4,\
  "../../5planet_stable_SEMENOV/test_relax2/gasopacity0120.cfg"                                                                             u (r($0)):($1/OPA2CU)                w l ls 5,\
  "../../5planet_inverse_NU2.0_-0.5/test_relax/gasopacity0060.cfg"                                                                          u (r($0)):($1/OPA2CU)                w l ls 2

########################################################################


